==> javascript-frontend-2.21.1.4786-sources.jar: org/sonar/plugins/javascript/api/tree/declaration/MethodDeclarationTree.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.plugins.javascript.api.tree.declaration;

import com.google.common.annotations.Beta;
import java.util.List;
import javax.annotation.Nullable;
import org.sonar.plugins.javascript.api.tree.Tree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;
import org.sonar.plugins.javascript.api.tree.statement.BlockTree;

/**
 * Common interface for all types <a href="https://people.mozilla.org/~jorendorff/es6-draft.html#sec-method-definitions">Method Definitions</a>
 * (<a href="http://wiki.ecmascript.org/doku.php?id=harmony:specification_drafts">ES6</a>).
 * <pre>
 *   {@link #name()} {@link #parameterClause()} {@link #body()}
 *   static {@link #name()} {@link #parameterClause()} {@link #body()}
 * </pre>
 */
@Beta
public interface MethodDeclarationTree extends FunctionTree {

  List<DecoratorTree> decorators();

  @Nullable
  SyntaxToken staticToken();

  Tree name();

  @Override
  ParameterListTree parameterClause();

  @Override
  BlockTree body();
}

==> javascript-frontend-3.1.0.5111-sources.jar: org/sonar/plugins/javascript/api/tree/declaration/MethodDeclarationTree.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.plugins.javascript.api.tree.declaration;

import com.google.common.annotations.Beta;
import java.util.List;
import javax.annotation.Nullable;
import org.sonar.plugins.javascript.api.tree.Tree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;
import org.sonar.plugins.javascript.api.tree.statement.BlockTree;

/**
 * Common interface for all types <a href="https://people.mozilla.org/~jorendorff/es6-draft.html#sec-method-definitions">Method Definitions</a>
 * (<a href="http://wiki.ecmascript.org/doku.php?id=harmony:specification_drafts">ES6</a>).
 * <pre>
 *   {@link #name()} {@link #parameterClause()} {@link #body()}
 *   static {@link #name()} {@link #parameterClause()} {@link #body()}
 *   {@link Tree.Kind#GENERATOR_METHOD *} {@link #name()} {@link #parameterClause()} {@link #body()}
 * </pre>
 */
@Beta
public interface MethodDeclarationTree extends FunctionTree {

  List<DecoratorTree> decorators();

  @Nullable
  SyntaxToken staticToken();

  @Nullable
  SyntaxToken starToken();

  @Override
  Tree name();

  @Override
  ParameterListTree parameterClause();

  @Override
  BlockTree body();
}
